Module builtins

Module builtins 

Built-in compression schemes that use only vortex-array encodings.

These schemes produce arrays using types already in vortex-array (DictArray, etc.) and have no external encoding crate dependencies.

Structs

BinaryDictScheme
Dictionary encoding for low-cardinality binary values.
FloatDictScheme
Dictionary encoding for low-cardinality float values.
IntDictScheme
Dictionary encoding for low-cardinality integer values.
StringDictScheme
Dictionary encoding for low-cardinality string values.

Functions

float_dictionary_encode
Compresses a floating-point array into a dictionary array according to attached stats.
integer_dictionary_encode
Compresses an integer array into a dictionary array according to attached stats.