pub enum CompressionEstimate {
Skip,
AlwaysUse,
Ratio(f64),
Sample,
Estimate(Box<EstimateFn>),
}Expand description
The result of a Scheme’s compression ratio estimation.
This type is returned by Scheme::expected_compression_ratio to tell the compressor how
promising this scheme is for a given array without performing any expensive work.
All expensive or fallible operations (sampling, trial encoding) are deferred to the compressor
via the Sample and Estimate
variants.
Variants
Skip
Do not use this scheme for this array.
AlwaysUse
Always use this scheme, as we know it is definitively the best choice.
Some examples include constant detection, decimal byte parts, and temporal decomposition.
The compressor will select this scheme immediately without evaluating further candidates.
Schemes that return AlwaysUse must be mutually exclusive per canonical type (enforced by
Scheme::matches), otherwise the winner depends silently on registration order.
Ratio(f64)
The estimated compression ratio. This must be greater than 1.0 to be considered by the
compressor, otherwise it is worse than the canonical encoding.
Sample
The scheme cannot cheaply estimate its ratio, so the compressor should compress a small sample to determine effectiveness.
Estimate(Box<EstimateFn>)
A fallible estimation requiring a custom expensive computation. The compressor will call the closure and handle the result.
Use this only when the scheme needs to perform trial encoding or other costly checks to determine its compression ratio.
The estimation function must not return a Sample or
Estimate variant to ensure the estimation process is
bounded.