Module scheme

Module scheme 

Everything a scheme author implements or receives: the Scheme trait, exclusion rules, compression estimates, and the compression context.

Structs

AncestorExclusion
Pull rule: declared by a scheme to exclude itself when the specified ancestor is in the cascade chain.
CompressorContext
Context passed through recursive compression calls.
DescendantExclusion
Push rule: declared by a cascading scheme to exclude another scheme from the subtree rooted at the specified children.
SchemeId
Unique identifier for a compression scheme.

Enums

ChildSelection
Selects which children of a cascading scheme a rule applies to.
CompressionEstimate
The result of a Scheme’s compression ratio estimation.
DeferredEstimate
Deferred work that can resolve to a terminal EstimateVerdict.
EstimateScore
Ranked estimate used for comparing non-terminal compression candidates.
EstimateVerdict
The terminal answer to a compression estimate request.

Constants

MAX_CASCADE
Maximum cascade depth for compression.

Traits

Scheme
A single compression encoding that the CascadingCompressor can select from.
SchemeExt
Extension trait providing id for all Scheme implementors.

Type Aliases

EstimateFn
Closure type for DeferredEstimate::Callback.