Module stats

Module stats 

Compression statistics types and caching.

Structs

ArrayAndStats
An array bundled with its lazily-computed statistics cache.
BoolStats
Array of booleans and relevant stats for compression.
FloatDistinctInfo
Information about the distinct values in a float array.
FloatStats
Array of floating-point numbers and relevant stats for compression.
FloatTypedStats
Typed statistics for a specific float type.
GenerateStatsOptions
Configures how stats are generated.
IntegerDistinctInfo
Information about the distinct values in an integer array.
IntegerStats
Array of integers and relevant stats for compression.
IntegerTypedStats
Typed statistics for a specific integer type.
StringStats
Array of variable-length byte arrays, and relevant stats for compression.

Enums

FloatErasedStats
Type-erased container for one of the TypedStats variants.
IntegerErasedStats
Type-erased container for one of the TypedStats variants.