pub enum IntegerErasedStats {
U8(TypedStats<u8>),
U16(TypedStats<u16>),
U32(TypedStats<u32>),
U64(TypedStats<u64>),
I8(TypedStats<i8>),
I16(TypedStats<i16>),
I32(TypedStats<i32>),
I64(TypedStats<i64>),
}Expand description
Type-erased container for one of the TypedStats variants.
Building the TypedStats is considerably faster and cheaper than building a type-erased
set of stats. We then perform a variety of access methods on them.
Variants
U8(TypedStats<u8>)
Stats for u8 arrays.
U16(TypedStats<u16>)
Stats for u16 arrays.
U32(TypedStats<u32>)
Stats for u32 arrays.
U64(TypedStats<u64>)
Stats for u64 arrays.
I8(TypedStats<i8>)
Stats for i8 arrays.
I16(TypedStats<i16>)
Stats for i16 arrays.
I32(TypedStats<i32>)
Stats for i32 arrays.
I64(TypedStats<i64>)
Stats for i64 arrays.
Implementations
Sourceimpl ErasedStats
impl ErasedStats
Sourcepub fn min_is_zero(&self) -> bool
pub fn min_is_zero(&self) -> bool
Returns true if the minimum value is zero.
Sourcepub fn min_is_negative(&self) -> bool
pub fn min_is_negative(&self) -> bool
Returns true if the minimum value is negative.
Sourcepub fn max_minus_min(&self) -> u64
pub fn max_minus_min(&self) -> u64
Difference between max and min.
Sourcepub fn max_ilog2(&self) -> Option<u32>
pub fn max_ilog2(&self) -> Option<u32>
Returns the ilog2 of the max value when transmuted to unsigned, or None if zero.
This matches how BitPacking computes bit width: it reinterprets signed values as
unsigned (preserving bit pattern) and uses leading_zeros. For non-negative signed
values, the transmuted value equals the original value.
This is used to determine if FOR encoding would reduce bit width compared to
direct BitPacking. If max_ilog2() == max_minus_min_ilog2(), FOR doesn’t help.
Sourcepub fn distinct_count(&self) -> Option<u32>
pub fn distinct_count(&self) -> Option<u32>
Get the count of distinct values, if we have computed it already.
Sourcepub fn most_frequent_value_and_count(&self) -> Option<(PValue, u32)>
pub fn most_frequent_value_and_count(&self) -> Option<(PValue, u32)>
Get the most commonly occurring value and its count.