pub struct BoolStats { /* private fields */ }Expand description
Array of booleans and relevant stats for compression.
Implementations
Sourceimpl BoolStats
impl BoolStats
Sourcepub fn generate(input: &BoolArray) -> VortexResult<Self>
pub fn generate(input: &BoolArray) -> VortexResult<Self>
Generates stats, returning an error on failure.
Errors
Returns an error if getting validity mask fails or values exceed u32 bounds.
Sourcepub fn null_count(&self) -> u32
pub fn null_count(&self) -> u32
Returns the number of null values.
Sourcepub fn value_count(&self) -> u32
pub fn value_count(&self) -> u32
Returns the number of non-null values.
Sourcepub fn true_count(&self) -> u32
pub fn true_count(&self) -> u32
Returns the number of true values among valid elements.
Sourcepub fn is_constant(&self) -> bool
pub fn is_constant(&self) -> bool
Returns true if all valid values are the same (all-true or all-false).