Crate vortex_compressor

Crate vortex_compressor 

Encoding-agnostic compression framework for Vortex arrays.

This crate provides the core compression engine: the Scheme trait, sampling-based ratio estimation, cascaded compression, and statistics infrastructure for deciding the best encoding scheme for an array.

This crate contains no encoding dependencies. Batteries-included compressors are provided by downstream crates like vortex-btrblocks, which register different encodings to the compressor.

Modules

builtins
Built-in compression schemes that use only vortex-array encodings.
ctx
Compression context for recursive compression.
estimate
Compression ratio estimation types and sampling-based estimation.
scheme
Unified compression scheme trait and exclusion rules.
stats
Compression statistics types and caching.

Structs

CascadingCompressor
The main compressor type implementing cascading adaptive compression.