Module builtins

Module builtins 

Built-in compression schemes that use only vortex-array encodings.

These schemes produce arrays using types already in vortex-array (ConstantArray, DictArray, MaskedArray, etc.) and have no external encoding crate dependencies.

Structs

BoolConstantScheme
Constant encoding for bool arrays where all valid values are the same.
FloatConstantScheme
Constant encoding for float arrays with a single distinct value.
FloatDictScheme
Dictionary encoding for low-cardinality float values.
IntConstantScheme
Constant encoding for integer arrays with a single distinct value.
IntDictScheme
Dictionary encoding for low-cardinality integer values.
StringConstantScheme
Constant encoding for string arrays with a single distinct value.
StringDictScheme
Dictionary encoding for low-cardinality string values.

Functions

float_dictionary_encode
Compresses a floating-point array into a dictionary array according to attached stats.
integer_dictionary_encode
Compresses an integer array into a dictionary array according to attached stats.
is_float_primitive
Returns true if the canonical form represents a floating-point primitive.
is_integer_primitive
Returns true if the canonical array is a primitive with an integer ptype.
is_utf8_string
Returns true if the canonical array is a UTF-8 string type.