Built-in compression schemes that use only vortex-array encodings.
These schemes produce arrays using types already in vortex-array (ConstantArray,
DictArray, MaskedArray, etc.) and have no external encoding crate dependencies.
Structs
- Bool
Constant Scheme - Constant encoding for bool arrays where all valid values are the same.
- Float
Constant Scheme - Constant encoding for float arrays with a single distinct value.
- Float
Dict Scheme - Dictionary encoding for low-cardinality float values.
- IntConstant
Scheme - Constant encoding for integer arrays with a single distinct value.
- IntDict
Scheme - Dictionary encoding for low-cardinality integer values.
- String
Constant Scheme - Constant encoding for string arrays with a single distinct value.
- String
Dict Scheme - Dictionary encoding for low-cardinality string values.
Functions
- float_
dictionary_ encode - Compresses a floating-point array into a dictionary array according to attached stats.
- integer_
dictionary_ encode - Compresses an integer array into a dictionary array according to attached stats.
- is_
float_ primitive - Returns
trueif the canonical form represents a floating-point primitive. - is_
integer_ primitive - Returns
trueif the canonical array is a primitive with an integer ptype. - is_
utf8_ string - Returns
trueif the canonical array is a UTF-8 string type.