Module scheme

Module scheme 

Unified compression scheme trait and exclusion rules.

Structs

AncestorExclusion
Pull rule: declared by a scheme to exclude itself when the specified ancestor is in the cascade chain.
DescendantExclusion
Push rule: declared by a cascading scheme to exclude another scheme from the subtree rooted at the specified children.
SchemeId
Unique identifier for a compression scheme.

Enums

ChildSelection
Selects which children of a cascading scheme a rule applies to.

Traits

Scheme
A single compression encoding that the CascadingCompressor can select from.
SchemeExt
Extension trait providing id for all Scheme implementors.